#10397: Compiler performance regression 7.6 -> 7.8 in elimCommonBlocks -------------------------------------+------------------------------------- Reporter: TobyGoodwin | Owner: Type: bug | Status: patch Priority: normal | Milestone: Component: Compiler | Version: 7.8.4 Resolution: | Keywords: Operating System: Unknown/Multiple | performance Type of failure: None/Unknown | Architecture: Blocked By: | Unknown/Multiple Related Tickets: | Test Case: see ticket | Blocking: | Differential Revisions: Phab:D892 -------------------------------------+------------------------------------- Comment (by nomeata): While working on this I found another bottleneck in the code generator, #10422. With that fixed¹ as well, we go from
<<ghc: 97671622904 bytes, 3397 GCs, 80319390/302142488 avg/max bytes residency (30 samples), 788M in use, 0.001 INIT (0.001 elapsed), 131.423 MUT (143.189 elapsed), 9.869 GC (9.877 elapsed) :ghc>>
to
<<ghc: 41423234208 bytes, 2190 GCs, 77441625/272967128 avg/max bytes residency (38 samples), 750M in use, 0.001 INIT (0.001 elapsed), 31.470 MUT (42.974 elapsed), 13.051 GC (13.059 elapsed) :ghc>>
Yay! ¹ patch pending validation, maybe I accidentially broke everything -- Ticket URL: <http://ghc.haskell.org/trac/ghc/ticket/10397#comment:13> GHC <http://www.haskell.org/ghc/> The Glasgow Haskell Compiler